==> haskell-quickcheck-instances-0.3.33-103.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-instances
version:              0.3.33
visibility:           public
id:                   quickcheck-instances-0.3.33-HOHYeHmWAjz1SmrXgJcTlH
key:                  quickcheck-instances-0.3.33-HOHYeHmWAjz1SmrXgJcTlH
license:              BSD-3-Clause
copyright:            Copyright 2012-2016 Antoine Latter, 2017-2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Antoine Latter <aslatter@gmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/qc-instances
synopsis:             Common quickcheck instances
description:
    QuickCheck instances.

    The goal is to supply QuickCheck instances for
    types provided by the Haskell Platform.

    Since all of these instances are provided as
    orphans, I recommend that you do not use this library
    within another library module, so that you don'\''t
    impose these instances on down-stream consumers of
    your code.

category:             Testing
abi:                  1bea4b836906e8d22837808d1c941580
exposed:              True
exposed-modules:
    Test.QuickCheck.Instances Test.QuickCheck.Instances.Array
    Test.QuickCheck.Instances.Array.Byte
    Test.QuickCheck.Instances.ByteString
    Test.QuickCheck.Instances.CaseInsensitive
    Test.QuickCheck.Instances.Containers
    Test.QuickCheck.Instances.DataFix
    Test.QuickCheck.Instances.Hashable
    Test.QuickCheck.Instances.Natural Test.QuickCheck.Instances.OldTime
    Test.QuickCheck.Instances.Primitive
    Test.QuickCheck.Instances.Scientific
    Test.QuickCheck.Instances.Semigroup Test.QuickCheck.Instances.Solo
    Test.QuickCheck.Instances.Strict Test.QuickCheck.Instances.Tagged
    Test.QuickCheck.Instances.Text Test.QuickCheck.Instances.Text.Short
    Test.QuickCheck.Instances.These Test.QuickCheck.Instances.Time
    Test.QuickCheck.Instances.Transformer
    Test.QuickCheck.Instances.UUID
    Test.QuickCheck.Instances.UnorderedContainers
    Test.QuickCheck.Instances.Vector Test.QuickCheck.Instances.Void

hidden-modules:       Test.QuickCheck.Instances.CustomPrelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/quickcheck-instances-0.3.33
library-dirs:         /usr/lib/ghc-9.6.6/site-local/quickcheck-instances-0.3.33
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/quickcheck-instances-0.3.33
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-instances
hs-libraries:         HSquickcheck-instances-0.3.33-HOHYeHmWAjz1SmrXgJcTlH
depends:
    OneTuple-0.4.2-6h1VpY4iGdO6wZSCEFOMPx
    QuickCheck-2.15.0.1-DMgRmI5QzBCFdvvi5liF0L array-0.5.6.0
    base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-3fPl2hvou1nDiCO1iE2i5z containers-0.6.7
    data-fix-0.3.4-DcHJ3ttKSJw5ofwAk9Vr2A
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    integer-logarithms-1.0.4-CFxTakyA1gmKMtDwn6V7ef
    old-time-1.1.0.4-3lD0LwNFkdkGhWCMuxpBlx
    primitive-0.9.1.0-FoKmvnfKMVpLetWIAmWZ
    scientific-0.3.8.0-3zIJLnW8aJ66FNwcOaEmTV
    splitmix-0.1.3-9CESEz75Upa7nQgfltLRDI
    strict-0.5.1-Kvxonrthq62FwakQ5ElNMl
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig text-2.0.2
    text-short-0.1.6-LT3hLgE3AIH5LX66Bu59Xl
    these-1.2.1-FiiqKcU92mLD4q4YanLE50
    time-compat-1.9.8-KXBZmSgVcbpGOqrx2hUfcV transformers-0.6.1.0
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu
    uuid-types-1.0.6-58FfeLal0FhHrTZjsfHNqD
    vector-0.13.2.0-L5lYsWFgdBEAgjlr9nnpMP

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-instances/html/quickcheck-instances.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-instances/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-instances-0.3.33-107-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-instances.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 quickcheck-instances
version:              0.3.33
visibility:           public
id:                   quickcheck-instances-0.3.33-5oVkVv7jygdKMiJ30iOjFQ
key:                  quickcheck-instances-0.3.33-5oVkVv7jygdKMiJ30iOjFQ
license:              BSD-3-Clause
copyright:            Copyright 2012-2016 Antoine Latter, 2017-2019 Oleg Grenrus
maintainer:           Oleg Grenrus <oleg.grenrus@iki.fi>
author:
    Antoine Latter <aslatter@gmail.com>, Oleg Grenrus <oleg.grenrus@iki.fi>

homepage:             https://github.com/haskellari/qc-instances
synopsis:             Common quickcheck instances
description:
    QuickCheck instances.

    The goal is to supply QuickCheck instances for
    types provided by the Haskell Platform.

    Since all of these instances are provided as
    orphans, I recommend that you do not use this library
    within another library module, so that you don'\''t
    impose these instances on down-stream consumers of
    your code.

category:             Testing
abi:                  0dbb9c3a44f23f0615286c158c450492
exposed:              True
exposed-modules:
    Test.QuickCheck.Instances Test.QuickCheck.Instances.Array
    Test.QuickCheck.Instances.Array.Byte
    Test.QuickCheck.Instances.ByteString
    Test.QuickCheck.Instances.CaseInsensitive
    Test.QuickCheck.Instances.Containers
    Test.QuickCheck.Instances.DataFix
    Test.QuickCheck.Instances.Hashable
    Test.QuickCheck.Instances.Natural Test.QuickCheck.Instances.OldTime
    Test.QuickCheck.Instances.Primitive
    Test.QuickCheck.Instances.Scientific
    Test.QuickCheck.Instances.Semigroup Test.QuickCheck.Instances.Solo
    Test.QuickCheck.Instances.Strict Test.QuickCheck.Instances.Tagged
    Test.QuickCheck.Instances.Text Test.QuickCheck.Instances.Text.Short
    Test.QuickCheck.Instances.These Test.QuickCheck.Instances.Time
    Test.QuickCheck.Instances.Transformer
    Test.QuickCheck.Instances.UUID
    Test.QuickCheck.Instances.UnorderedContainers
    Test.QuickCheck.Instances.Vector Test.QuickCheck.Instances.Void

hidden-modules:       Test.QuickCheck.Instances.CustomPrelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/quickcheck-instances-0.3.33
library-dirs:         /usr/lib/ghc-9.6.6/site-local/quickcheck-instances-0.3.33
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/quickcheck-instances-0.3.33
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-instances
hs-libraries:         HSquickcheck-instances-0.3.33-5oVkVv7jygdKMiJ30iOjFQ
depends:
    OneTuple-0.4.2-6pEN3mXYu4CEsP59PDdiWd
    QuickCheck-2.15.0.1-1xFq7rzYyJMIIsLto0YgsS array-0.5.6.0
    base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-KNymwxzPyypAOJSQGx0ioI containers-0.6.7
    data-fix-0.3.4-3won58iaWYcBjetskLCnc9
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    integer-logarithms-1.0.4-FdQWCBDkueQ90Hs3A6705t
    old-time-1.1.0.4-3lD0LwNFkdkGhWCMuxpBlx
    primitive-0.9.1.0-Gw11eCcStSPCrwBXmVDBSi
    scientific-0.3.8.0-JR5ijS18eRDLRLPoHGHkyW
    splitmix-0.1.3-90QrqABg5SpKi5FtNwnDR8
    strict-0.5.1-FbuUXvHHt04IVZ1UpYOqLR
    tagged-0.8.9-2fCpivRH6QIGdlOWfdc5ig text-2.0.2
    text-short-0.1.6-uDJBdqgRh39kcxwO1KbRc
    these-1.2.1-FFxH0GxUZUDAtgQSChMM1W
    time-compat-1.9.8-ITy6Cf33IaSAWRM66COV33 transformers-0.6.1.0
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5
    uuid-types-1.0.6-21TzNsexUnW19QIZkyQGNe
    vector-0.13.2.0-eGaPlIkScLKlfBYQuI3vH

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-instances/html/quickcheck-instances.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-instances/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
